@@ -77,6 +77,7 @@ class TestClassicBuilder(TestCase):
             with_with_proposed=None,
             extra_ppas=None,
             hooks_directory=[],
+            disk_info=None,
             gadget_tree=self.gadget_tree,
             filesystem=None,
             )
@@ -119,6 +120,7 @@ class TestClassicBuilder(TestCase):
             with_proposed='1',
             extra_ppas='ppa:some/ppa',
             hooks_directory=[],
+            disk_info=None,
             gadget_tree=self.gadget_tree,
             filesystem=None,
             )
@@ -163,6 +165,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -219,6 +222,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -275,6 +279,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -333,6 +338,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -391,6 +397,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -431,7 +438,10 @@ class TestClassicBuilder(TestCase):
             with open(meta_data, 'r', encoding='utf-8') as fp:
                 self.assertEqual(fp.read(), 'instance-id: nocloud-static\n')
 
-    def test_populate_rootfs_contents_grub_boot_remove(self):
+    def test_populate_rootfs_contents_grub_boot_preserved(self):
+        # We changed our design, so this test is here to make sure the new
+        # design of preserving /boot/grub works.  Previously we removed all
+        # contents of that directory, leaving it empty.
         with ExitStack() as resources:
             workdir = resources.enter_context(TemporaryDirectory())
             args = SimpleNamespace(
@@ -448,6 +458,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -484,10 +495,10 @@ class TestClassicBuilder(TestCase):
             state._next.pop()
             state._next.append(state.populate_rootfs_contents)
             next(state)
-            # /boot/grub should persist, but not the files inside
+            # /boot/grub should persist
             self.assertTrue(os.path.exists(grub_dir))
-            self.assertFalse(os.path.exists(grub_inside_dir))
-            self.assertFalse(os.path.exists(grub_file))
+            self.assertTrue(os.path.exists(grub_inside_dir))
+            self.assertTrue(os.path.exists(grub_file))
 
     def test_populate_bootfs_contents(self):
         # This test provides coverage for populate_bootfs_contents() when a
@@ -515,6 +526,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -606,6 +618,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -658,6 +671,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -719,6 +733,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -825,6 +840,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -873,6 +889,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
@@ -916,6 +933,7 @@ class TestClassicBuilder(TestCase):
                 'workdir': '/tmp',
                 'output_dir': '/tmp',
                 'hooks_directory': '/tmp',
+                'disk_info': None,
                 'output': None,
                 'cloud_init': None,
                 'gadget_tree': None,
@@ -984,6 +1002,7 @@ class TestClassicBuilder(TestCase):
                 'workdir': '/tmp',
                 'output_dir': '/tmp',
                 'hooks_directory': '/tmp',
+                'disk_info': None,
                 'output': None,
                 'cloud_init': None,
                 'gadget_tree': None,
@@ -1036,6 +1055,7 @@ class TestClassicBuilder(TestCase):
                 with_proposed=None,
                 extra_ppas=None,
                 hooks_directory=[],
+                disk_info=None,
                 gadget_tree=self.gadget_tree,
                 filesystem=None,
                 )
